@@ -353,6 +353,7 @@
 #define __NR_pkey_alloc	395
 #define __NR_pkey_free	396
 #define __NR_statx	397
+#define __NR_rseq	398
 
 #define __ARM_NR_breakpoint	0x0f0001
 #define __ARM_NR_cacheflush	0x0f0002
@@ -716,3 +717,4 @@
 #define SYS_pkey_alloc	395
 #define SYS_pkey_free	396
 #define SYS_statx	397
+#define SYS_rseq	398
